@@ -178,7 +178,16 @@ class AnonymousStrategy(Strategy):
         except:
             debug(tag, 'Failed to accept cookies')
 
-    def run(self, driver: webdriver, search_url: str, query: Query, location: str, apply_link: bool) -> None:
+    def run(
+        self,
+        driver: webdriver,
+        search_url: str,
+        query: Query,
+        location: str,
+        apply_link: bool,
+        page_load_timeout: int,
+        apply_page_load_timeout: int
+    ) -> None:
         """
         Run scraper
         :param driver: webdriver
@@ -186,6 +195,8 @@ class AnonymousStrategy(Strategy):
         :param query: Query
         :param location: str
         :param apply_link: bool
+        :param page_load_timeout: int
+        :param apply_page_load_timeout: int
         :return: None
         """
 
